@@ -29,9 +29,6 @@ pub use self::policy::*;
 pub use self::state::*;
 pub use self::types::*;
 
-#[cfg(feature = "wasm")]
-pub const WASM_BINARY: &[u8] = include_bytes!(env!("WASM_BINARY"));
-
 wasm_trampoline!(Actor);
 
 #[doc(hidden)]
